pub enum DetrendStrategy {
Linear,
Custom(Box<dyn DetrendAlgorithm + Sync + Send>),
}Expand description
Available detrend strategies for the DFA algorithm.
user provided algorithms can be passed via the Custom variant.
Variants
Linear
Linear detrending algorithm using least squares regression.
Custom(Box<dyn DetrendAlgorithm + Sync + Send>)
A custom detrending algorithm that implements the DetrendAlgorithm trait.
The algorithm is wrapped in a Box to allow for dynamic dispatch and must
also implement the Sync and Send traits to ensure thread safety.