This module contains submodules for preprocessing tasks in HRV algorithms.
The noise submodule provides functionalities to add noise to quantised data.
The outliers submodule offers tools to detect and manage outliers in the dataset.