LinearInterpolation

Struct LinearInterpolation 

pub struct LinearInterpolation;
Linear interpolation between neighbors

The interpolated value is based on the linear interpolation of the two neighbors. If the index is at the beginning or end of the window, the value is extrapolated.

Examples

use hrv_algos::preprocessing::outliers::LinearInterpolation;
use hrv_algos::preprocessing::outliers::Interpolator;
let window = vec![1.0, 2.0, 5.0];
let interpolator = LinearInterpolation;
// the interpolated value is the average of the neighbors
assert_eq!(interpolator.interpolate(&window, 1).unwrap(), 3.0);
//rhe extrapolated value is 2.0 - (5.0 - 2.0) = -1.0
assert_eq!(interpolator.interpolate(&window, 0).unwrap(), -1.0);
// the extrapolated value is 2.0 + (2.0 - 1.0) = 3.0
assert_eq!(interpolator.interpolate(&window, 2).unwrap(), 3.0);