pub struct MovingQuantileFilter { /* private fields */ }Expand description
Detects artefacts (ectopic, long, short, missed, extra beats) in an RR interval series using rolling quantiles and threshold-based classification.
The algorithm is based on the Systole Python package by Legrand and Allen (2022). Link: https://github.com/embodied-computation-group/systole
References
- Legrand, N. & Allen, M., (2022). Systole: A python package for cardiac signal synchrony and analysis. Journal of Open Source Software, 7(69), 3832, https://doi.org/10.21105/joss.03832
Implementations
Sourceimpl MovingQuantileFilter
impl MovingQuantileFilter
Sourcepub fn new(
slope: Option<f64>,
intercept: Option<f64>,
quantile_scale: Option<f64>,
) -> Self
pub fn new( slope: Option<f64>, intercept: Option<f64>, quantile_scale: Option<f64>, ) -> Self
Creates a new MovingQuantileFilter instance.
The default values for slope, intercept, and quantile scale are 0.13, 0.17, and 5.2, respectively.
The default window sizes for median and threshold calculations are 11 and 91, respectively.
Arguments
slope- The slope value for the threshold calculation. Default is 0.13.intercept- The intercept value for the threshold calculation. Default is 0.17.quantile_scale- The scaling factor for the threshold calculation. Default is 5.2.
Returns
A new MovingQuantileFilter instance.
Sourcepub fn set_intercept(&mut self, intercept: f64) -> Result<()>
pub fn set_intercept(&mut self, intercept: f64) -> Result<()>
Sourcepub fn set_quantile_scale(&mut self, quantile_scale: f64) -> Result<()>
pub fn set_quantile_scale(&mut self, quantile_scale: f64) -> Result<()>
pub fn get_slope(&self) -> f64
pub fn get_intercept(&self) -> f64
pub fn get_quantile_scale(&self) -> f64