pub struct StdDevCriterion {
pub ratio: f64,
}Expand description
Criterion for outlier detection based on a ratio of the value to the standard deviation of a window.
The criterion is acceptable if the value is within the mean +/- ratio * standard deviation.
Arguments
ratio- The ratio to use for comparison.
Fields
ratio: f64Trait Implementations
Sourceimpl OutlierCriterion for StdDevCriterion
impl OutlierCriterion for StdDevCriterion